@@ -22,11 +22,11 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
+from decimal import Decimal
 import sys
-from typing import Dict, Generator, List, TYPE_CHECKING
+from typing import Any, Dict, Generator, List, Set, TYPE_CHECKING, Union
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_dynamodb.type_defs import (
-    AttributeValueTypeDef,
     ConditionTypeDef,
     ListBackupsOutputTypeDef,
     ListTablesOutputTypeDef,
@@ -53,7 +53,7 @@ __all__ = (
 
 class ListBackupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
+    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
     """
 
     def paginate(
@@ -65,39 +65,39 @@ class ListBackupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Generator[ListBackupsOutputTypeDef, None, None]:
         """
-        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
+        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
+    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListTablesOutputTypeDef, None, None]:
         """
-        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
+        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         """
 
 
 class ListTagsOfResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
+    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListTagsOfResourceOutputTypeDef, None, None]:
         """
-        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
+        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         """
 
 
 class QueryPaginator(Boto3Paginator):
     """
-    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
+    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
     """
 
     def paginate(
@@ -118,17 +118,35 @@ class QueryPaginator(Boto3Paginator):
         FilterExpression: str = None,
         KeyConditionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[str, AttributeValueTypeDef] = None,
+        ExpressionAttributeValues: Dict[
+            str,
+            Union[
+                bytes,
+                bytearray,
+                str,
+                int,
+                Decimal,
+                bool,
+                Set[int],
+                Set[Decimal],
+                Set[str],
+                Set[bytes],
+                Set[bytearray],
+                List[Any],
+                Dict[str, Any],
+                None,
+            ],
+        ] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Generator[QueryOutputTypeDef, None, None]:
         """
-        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
+        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         """
 
 
 class ScanPaginator(Boto3Paginator):
     """
-    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
+    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
     """
 
     def paginate(
@@ -147,10 +165,28 @@ class ScanPaginator(Boto3Paginator):
         ProjectionExpression: str = None,
         FilterExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[str, AttributeValueTypeDef] = None,
+        ExpressionAttributeValues: Dict[
+            str,
+            Union[
+                bytes,
+                bytearray,
+                str,
+                int,
+                Decimal,
+                bool,
+                Set[int],
+                Set[Decimal],
+                Set[str],
+                Set[bytes],
+                Set[bytearray],
+                List[Any],
+                Dict[str, Any],
+                None,
+            ],
+        ] = None,
         ConsistentRead: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Generator[ScanOutputTypeDef, None, None]:
         """
-        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.5/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
+        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         """
